@@ -1,6 +1,6 @@
 package Facebook::Cookie;
 BEGIN {
-  $Facebook::Cookie::VERSION = '0.006';
+  $Facebook::Cookie::VERSION = '0.007';
 }
 # ABSTRACT: Analyzed and signed Facebook Cookie reflection
 
@@ -119,7 +119,7 @@ Facebook::Cookie - Analyzed and signed Facebook Cookie reflection
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 SYNOPSIS
 
@@ -226,11 +226,11 @@ Gives back the signed base_domain of the cookie given
 
 =head1 AUTHOR
 
-Torsten Raudssus <torsten@raudssus.de>
+Torsten Raudssus <torsten@raudssus.de> L<http://www.raudssus.de/>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Facebook Distribution Authors.
+This software is copyright (c) 2010 by Raudssus Social Software & Facebook Distribution Authors.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
